/*
 *  
 *  $Id: visualizator.h 4555 2012-01-17 10:03:03Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once
#include <prvext/prvext.h>

#include <wx/dynlib.h>
#include <api/imodulo.h>

class GNKVisualizatorExtension : public PrivateExtension
{
public :
	GNKVisualizatorExtension();
	~GNKVisualizatorExtension();
	virtual PrivateExtension::TListControllers InitializeLibrary(GNC::GCS::IEntorno* pEntorno);
	virtual bool IsActivated();
	virtual void ShowActivationDialog(wxWindow* pParent);
};